.. skvai documentation master file, created by
   sphinx-quickstart on Wed Apr 23 20:03:05 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

skvai documentation
===================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules


